summaryrefslogtreecommitdiffstats
path: root/src/gui/editors/notation/TrackHeader.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/editors/notation/TrackHeader.h')
-rw-r--r--src/gui/editors/notation/TrackHeader.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/gui/editors/notation/TrackHeader.h b/src/gui/editors/notation/TrackHeader.h
index 0b8a0a6..3f7029e 100644
--- a/src/gui/editors/notation/TrackHeader.h
+++ b/src/gui/editors/notation/TrackHeader.h
@@ -57,10 +57,10 @@ class TrackHeader : public TQLabel
public:
/**
* Create a new track header for track of id trackId.
* *tqparent is the tqparent widget, height the height of staff and
* ypos is the staff y position on canvas.
*/
- TrackHeader(TQWidget *tqparent, TrackId trackId, int height, int ypos);
+ TrackHeader(TQWidget *parent, TrackId trackId, int height, int ypos);
/**
* Draw a blue line around header when current is true
@@ -57,10 +57,10 @@ class TrackHeader : public TQLabel
/**
* Create a new track header for track of id trackId.
- * *tqparent is the tqparent widget, height the height of staff and
+ * *parent is the parent widget, height the height of staff and
* ypos is the staff y position on canvas.
*/